pub struct CanvasFont {
pub identifier: FontIdentifier,
pub data: Option<FontDataAndIndex>,
}Fields
identifier: FontIdentifierA FontIdentifier for this CanvasFont, maybe either Local or Web.
data: Option<FontDataAndIndex>If this font is a web font, this field contains the data for the font. If
the font is a local font, it will be None.
Implementations
Sourceimpl CanvasFont
impl CanvasFont
pub fn font_data_and_index(&self) -> Option<FontDataAndIndex>